@@ -1,6 +1,6 @@
 sub Mojo::Webqq::Client::_login2{
     my $self = shift;
-    $self->info("尝试进行登录(阶段2)...\n");
+    $self->info("尝试进行登录(2)...\n");
     my $api_url = 'http://d.web2.qq.com/channel/login2';
     my $headers = {
         Referer     => 'http://d.web2.qq.com/proxy.html?v=20130916001&callback=1&id=2',
