@@ -6,7 +6,6 @@ sub dump{
     my $self = shift;
     my $clone = {};
     my $obj_name = blessed($self);
-    bless $clone,$obj_name if $obj_name;
     for(keys %$self){
         next if $_ eq "_client";
         if(my $n=blessed($self->{$_})){
@@ -20,10 +19,37 @@ sub dump{
             $clone->{$_} = $self->{$_};
         }
     }
-    print Dumper $clone;
+    local $Data::Dumper::Indent = 1;
+    local $Data::Dumper::Terse = 1;
+    $self->{_client}->print("Object($obj_name) " . Data::Dumper::Dumper($clone));
     return $self;
 }
 
+sub is_at{
+    my $self = shift;
+    my $object;
+    my $displayname;
+    if($self->msg_class eq "recv"){
+        $object = shift || $self->receiver;
+        $displayname = $object->displayname;
+    }
+    elsif($self->msg_class eq "send"){
+        if($self->type eq "group"){
+            $object = shift || $self->group->me;
+            $displayname = $object->displayname;
+        } 
+        elsif($self->type eq "discuss"){
+            $object = shift || $self->discuss->me;
+            $displayname = $object->displayname;
+        }
+        elsif($self->type=~/^message|sess_message$/){
+            $object = shift || $self->receiver;
+            $displayname = $object->displayname;
+        }
+    }
+    return $self->content =~/\@\Q$displayname\E /; 
+}
+
 sub to_json{
     my $self = shift;
     my $json = {};
