@@ -10,4 +10,9 @@ has msg_from     => "none";
 has ttl          => 5;
 has allow_plugin => 1;
 has [qw(msg_id discuss_id sender_id receiver_id msg_time sender receiver discuss content raw_content)];
+sub text {
+    my $self = shift;
+    return $self->content if ref $self->raw_content ne "ARRAY";
+    return join "",map{$_->{content}} grep {$_->{type} eq "txt"} @{$self->{raw_content}};
+}
 1;
