@@ -4,7 +4,13 @@ sub gen_url{
     my $self = shift;
     my ($url,@query_string) = @_;
     my @query_string_pairs;
-    push @query_string_pairs , shift(@query_string) . "=" . shift(@query_string) while(@query_string);
+    while(@query_string){
+        my $key = shift(@query_string);
+        my $val = shift(@query_string);
+        $key = "" if not defined $key;
+        $val = "" if not defined $val;
+        push @query_string_pairs , $key . "=" . $val;
+    }
     return $url . '?' . join("&",@query_string_pairs);    
 }
 sub http_get{
@@ -18,10 +24,10 @@ sub http_post{
 sub _http_request{
     my $self = shift;
     my $method = shift;
-    my %opt = ();
+    my %opt = (json=>0,retry_times=>$self->ua_retry_times);
     if(ref $_[1] eq "HASH"){#with header or option
-        $opt{json} = delete $_[1]->{json} || 0;
-        $opt{retry_times} = delete $_[1]->{retry_times} || $self->ua_retry_times;
+        $opt{json} = delete $_[1]->{json} if defined $_[1]->{json};
+        $opt{retry_times} = delete $_[1]->{retry_times} if defined $_[1]->{retry_times};
     }
     if(ref $_[-1] eq "CODE"){
         my $cb = pop;
@@ -36,12 +42,16 @@ sub _http_request{
                 }
                 else{$cb->($r,$ua,$tx);}
             }
-            else{$cb->(undef,$ua,$tx);}
+            elsif(defined $tx){
+                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . $tx->error->{message});
+                $cb->(undef,$ua,$tx);
+            }
         });
     }
     else{
+        my $tx;
         for(my $i=0;$i<=$opt{retry_times};$i++){
-            my $tx = $self->ua->$method(@_);
+            $tx = $self->ua->$method(@_);
             $self->save_cookie();
             if(defined $tx and $tx->success){
                 my $r = eval{$opt{json}?$tx->res->json:$tx->res->body;};
@@ -53,7 +63,11 @@ sub _http_request{
                     return wantarray?($r,$self->ua,$tx):$r;
                 }
             }
+            elsif(defined $tx){
+                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code} || "-") . " " . $tx->error->{message});
+            }
         }
+        $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . $tx->error->{message}) if defined $tx;
         return wantarray?(undef,$self->ua,$tx):undef;
     }
 }
